@@ -12,7 +12,7 @@ MooseX::Types::CanonOpenModeStr - Type for canonical open mode string
   use Moose;
   use MooseX::Types::CanonOpenModeStr;
   has file => ( isa => 'Str' );
-  has mode => ( isa => 'CanonOpenModeStr' );
+  has mode => ( isa => 'CanonOpenModeStr', coerce => 1 );
 
   package main;
   # This will be coerced
@@ -31,7 +31,7 @@ mode string (i.e. "+>").
 use strict;
 use warnings;
 
-our $VERSION = 0.06_02;
+our $VERSION = '0.07';
 
 use Moose::Util::TypeConstraints;
 
